Stan Math Library: stan/math/fwd/scal/fun/erf.hpp Source File

| Stan Math Library 2.10.0 reverse mode automatic differentiation

- Main Page
- Modules
- Namespaces
- Classes
- Files

- File List
- File Members

erf.hpp
Go to the documentation of this file.
1 #ifndef STAN_MATH_FWD_SCAL_FUN_ERF_HPP
2 #define STAN_MATH_FWD_SCAL_FUN_ERF_HPP
3
4 #include <math.h>
5 #include <stan/math/fwd/core.hpp>
6 #include <stan/math/prim/scal/fun/constants.hpp>
7 #include <stan/math/prim/scal/fun/square.hpp>
8 #include <cmath>
9
10 namespace stan {
11 namespace math {
12
13 template <typename T>
14 inline fvar<T> erf(const fvar<T>& x) {
15 using ::erf;
16 using std::sqrt;
17 using std::exp;
18 using stan::math::square;
19 return fvar<T>(erf(x.val_), x.d_ * exp(-square(x.val_))
20 * stan::math::TWO_OVER_SQRT_PI);
21 }
22
23 }
24 }
25 #endif
stan::math::erf
var erf(const var &a)
The error function for variables (C99).
Definition: erf.hpp:68
core.hpp
stan::math::fvar::d_
T d_
Definition: fvar.hpp:15
stan::math::sqrt
fvar< T > sqrt(const fvar< T > &x)
Definition: sqrt.hpp:15
stan
Definition: log_sum_exp.hpp:8
square.hpp
stan::math::erf
fvar< T > erf(const fvar< T > &x)
Definition: erf.hpp:14
stan::math::square
fvar< T > square(const fvar< T > &x)
Definition: square.hpp:15
stan::math::TWO_OVER_SQRT_PI
const double TWO_OVER_SQRT_PI
Definition: constants.hpp:161
stan::math::fvar::val_
T val_
Definition: fvar.hpp:14
stan::math::exp
fvar< T > exp(const fvar< T > &x)
Definition: exp.hpp:10
constants.hpp
stan::math::fvar
Definition: fvar.hpp:13

[ Stan Home Page ] © 2011–2016, Stan Development Team.